@@ -778,11 +778,11 @@ class Objective:
             # 最適化するべきパラメータ
             params_ = {
                 'Base': DecisionTreeRegressor(
-                    max_depth =  trial.suggest_int('_max_depth', 2, 100),
+                    max_depth =  trial.suggest_int('_max_depth', 2, 10),
                     criterion = trial.suggest_categorical('_criterion', ['mse', 'friedman_mse']),
                     random_state = self.rng,
                 ),
-                'n_estimators' : trial.suggest_int('n_estimators', 100, 2000),
+                'n_estimators' : trial.suggest_int('n_estimators', 500, 10000, log = True),
                 'minibatch_frac': trial.suggest_uniform('minibatch_frac', 0.5, 1.0),
             }
             # 固定するパラメータ (外でも取り出せるようにインスタンス変数としてる．)
